@@ -6,8 +6,5 @@ DIR=`dirname $0`
 
 args=$@
 
-if [ -e /usr/bin/python2 ]; then
-    args="$args PYTHON=/usr/bin/python2"
-fi
 AUTOPOINT='intltoolize' autoreconf --install --force $DIR
 $DIR/configure $args
