@@ -17,9 +17,6 @@
 # You should have received a copy of the GNU General Public License
 # along with OSD Lyrics.  If not, see <https://www.gnu.org/licenses/>.
 #
-from __future__ import unicode_literals
-from builtins import object, super
-from future.utils import raise_from
 
 from abc import abstractmethod
 import logging
@@ -34,7 +31,7 @@ from .consts import (MPRIS2_PLAYER_INTERFACE, PLAYER_PROXY_INTERFACE,
 from .dbusext.service import Object as DBusObject, property as dbus_property
 
 
-class CAPS(object):
+class CAPS:
     NEXT = 1 << 0
     PREV = 1 << 1
     PAUSE = 1 << 2
@@ -43,13 +40,13 @@ class CAPS(object):
     PROVIDE_METADATA = 1 << 5
 
 
-class REPEAT(object):
+class REPEAT:
     NONE = 0
     TRACK = 1
     ALL = 2
 
 
-class STATUS(object):
+class STATUS:
     PLAYING = 0
     PAUSED = 1
     STOPPED = 2
@@ -114,9 +111,9 @@ class BasePlayerProxy(dbus.service.Object):
         try:
             player = self.do_connect_player(player_name)
         except TypeError as e:
-            raise_from(errors.BaseError(
+            raise errors.BaseError(
                 '%s cannot instantiate Player[%s, %s]' % (type(self).__name__, self.name, player_name)
-            ), e)
+            ) from e
         if player and player.connected:
             player.set_disconnect_cb(self._player_lost_cb)
             self._connected_players[player_name] = player
@@ -172,7 +169,7 @@ class BasePlayerProxy(dbus.service.Object):
         raise NotImplementedError()
 
 
-class PlayerInfo(object):
+class PlayerInfo:
     """Information about a supported player
     """
 
